Windows: Switch wrapper-less CROSSTOOL to default

set USE_MSVC_WRAPPER=1 if you still want to use wrapper script.

RELNOTES:
Windows: Wrapper-less CROSSTOOL becomes default now.
set USE_MSVC_WRAPPER=1 if you still want to use wrapper script.
PiperOrigin-RevId: 161654018
diff --git a/tools/cpp/windows_cc_configure.bzl b/tools/cpp/windows_cc_configure.bzl
index 657277d..8f6600f 100644
--- a/tools/cpp/windows_cc_configure.bzl
+++ b/tools/cpp/windows_cc_configure.bzl
@@ -264,10 +264,10 @@
   return crt_library + ".lib"
 
 
-def _is_no_msvc_wrapper(repository_ctx):
-  """Returns True if NO_MSVC_WRAPPER is set to 1."""
+def _is_use_msvc_wrapper(repository_ctx):
+  """Returns True if USE_MSVC_WRAPPER is set to 1."""
   env = repository_ctx.os.environ
-  return "NO_MSVC_WRAPPER" in env and env["NO_MSVC_WRAPPER"] == "1"
+  return "USE_MSVC_WRAPPER" in env and env["USE_MSVC_WRAPPER"] == "1"
 
 
 def _get_compilation_mode_content():
@@ -324,7 +324,7 @@
   escaped_cxx_include_directories = []
   compilation_mode_content = ""
 
-  if not _is_no_msvc_wrapper(repository_ctx):
+  if _is_use_msvc_wrapper(repository_ctx):
     if _is_support_whole_archive(repository_ctx, vc_path):
       support_whole_archive = "True"
     else: